@@ -6,9 +6,9 @@
 # Updated and turned into general-purpose library by Gene Cash
 # <gcash@cfl.rr.com>
 #
-# This copyright license is intended to be similar to the FreeBSD license. 
+# This copyright license is intended to be similar to the FreeBSD license.
 #
-# Copyright 2002 Gene Cash All rights reserved. 
+# Copyright 2002 Gene Cash All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are
@@ -335,7 +335,7 @@ def olympus_special_mode(v):
         3: 'Bottom to top',
         4: 'Top to bottom'}
     return '%s - sequence %d - %s' % (a[v[0]], v[1], b[v[2]])
-        
+
 MAKERNOTE_OLYMPUS_TAGS = {
     # ah HAH! those sneeeeeaky bastids! this is how they get past the fact
     # that a JPEG thumbnail is not allowed in an uncompressed TIFF file
@@ -352,7 +352,7 @@ MAKERNOTE_OLYMPUS_TAGS = {
     0x0207: ('SoftwareRelease',  ),
     0x0208: ('PictureInfo',  ),
     # print as string
-    0x0209: ('CameraID', lambda x: ''.join(map(chr, x))), 
+    0x0209: ('CameraID', lambda x: ''.join(map(chr, x))),
     0x0F00: ('DataDump',  )
     }
 
@@ -620,7 +620,7 @@ MAKERNOTE_CANON_TAG_0x004 = {
          0X002C: '1.33 EV',
          0X0030: '1.50 EV',
          0X0034: '1.67 EV',
-         0X0040: '2 EV'}), 
+         0X0040: '2 EV'}),
     19: ('SubjectDistance', )
     }
 
@@ -675,10 +675,10 @@ class IFD_Tag:
         self.field_offset = field_offset
         self.field_length = field_length
         self.values = values
-        
+
     def __str__(self):
         return self.printable
-    
+
     def __repr__(self):
         return '(0x%04X) %s = %s @ %d' % (self.tag,
                                         FIELD_TYPES[self.field_type][2],
@@ -693,7 +693,7 @@ class EXIF_header:
         self.offset = offset
         self.debug = debug
         self.tags = {}
-        
+
     # convert slice to integer, based on sign and endian flags
     def s2n(self, offset, length, signed = 0):
         self.file.seek(self.offset+offset)
@@ -703,6 +703,12 @@ class EXIF_header:
         else:
             val = s2n_motorola(slice)
         # Sign extension ?
+        """ #TODO0: remove futurewarning here:
+
+/home/rnc/prj/imgseek/imgSeekLib/EXIF.py:707: FutureWarning: x<<y losing bits or changing sign will return a long in Python 2.4 and up
+  msb = 1 << (8*length-1)
+
+        """
         if signed:
             msb = 1 << (8*length-1)
             if val & msb:
@@ -719,7 +725,7 @@ class EXIF_header:
                 s = chr(offset & 0xFF)+s
             offset = offset >> 8
         return s
-    
+
     # return first IFD
     def first_IFD(self):
         return self.s2n(4, 4)
@@ -818,7 +824,7 @@ class EXIF_header:
         # ... plus thumbnail IFD data plus a null "next IFD" pointer
         self.file.seek(self.offset+thumb_ifd)
         tiff+= self.file.read(entries*12+2)+'\x00\x00\x00\x00'
-        
+
         # fix up large value offset pointers into data area
         for i in range(entries):
             entry = thumb_ifd+2+12*i
@@ -846,7 +852,7 @@ class EXIF_header:
                 # get original data and store it
                 self.file.seek(self.offset+oldoff)
                 tiff+= self.file.read(count*typelen)
-                
+
         # add pixel strips and update strip offset info
         old_offsets = self.tags['Thumbnail StripOffsets'].values
         old_counts = self.tags['Thumbnail StripByteCounts'].values
@@ -858,9 +864,9 @@ class EXIF_header:
             # add pixel strip to end
             self.file.seek(self.offset+old_offsets[i])
             tiff+= self.file.read(old_counts[i])
-            
+
         self.tags['TIFFThumbnail'] = tiff
-        
+
     # decode all the camera-specific MakerNote formats
     def decode_maker_note(self):
         note = self.tags['EXIF MakerNote']
@@ -891,11 +897,11 @@ class EXIF_header:
             self.dump_IFD(note.field_offset, 'MakerNote',
                           dict = MAKERNOTE_CASIO_TAGS)
             return
-        
+
         # Fujifilm
         if make == 'FUJIFILM':
             # bug: everything else is "Motorola" endian, but the MakerNote
-            # is "Intel" endian 
+            # is "Intel" endian
             endian = self.endian
             self.endian = 'I'
             # bug: IFD offsets are from beginning of MakerNote, not
@@ -908,7 +914,7 @@ class EXIF_header:
             self.endian = endian
             self.offset = offset
             return
-        
+
         # Canon
         if make == 'Canon':
             self.dump_IFD(note.field_offset, 'MakerNote',
@@ -1006,14 +1012,14 @@ def process_file(file, debug = 0):
     thumb = hdr.tags.get('Thumbnail Compression')
     if thumb and thumb.printable == 'Uncompressed TIFF':
         hdr.extract_TIFF_thumbnail(thumb_ifd)
-        
+
     # JPEG thumbnail (thankfully the JPEG data is stored as a unit)
     thumb_off = hdr.tags.get('Thumbnail JPEGInterchangeFormat')
     if thumb_off:
         file.seek(offset+thumb_off.values[0])
         size = hdr.tags['Thumbnail JPEGInterchangeFormatLength'].values[0]
         hdr.tags['JPEGThumbnail'] = file.read(size)
-        
+
     # deal with MakerNote contained in EXIF IFD
     if hdr.tags.has_key('EXIF MakerNote'):
         hdr.decode_maker_note()
@@ -1025,18 +1031,18 @@ def process_file(file, debug = 0):
         if thumb_off:
             file.seek(offset+thumb_off.values[0])
             hdr.tags['JPEGThumbnail'] = file.read(thumb_off.field_length)
-            
+
     file.close()
     return hdr.tags
 
 # library test/debug function (dump given files)
 if __name__ == '__main__':
     import sys
-    
+
     if len(sys.argv) < 2:
         print 'Usage: %s files...\n' % sys.argv[0]
         sys.exit(0)
-        
+
     for filename in sys.argv[1:]:
         try:
             file = open(filename, 'rb')
