@@ -1,9 +1,10 @@
+# -*- coding: iso-8859-1 -*-
 """ HTML Album module
 
     begin                : Sat Dec 14 2002
     author               : (C) 2002 by Ricardo Niederberger Cabral
     email                : nieder|at|mail.ru
-    $Id: HTMLAlbum.py,v 1.32 2004/02/27 19:52:05 niederberger Exp $
+    $Id: HTMLAlbum.py,v 1.35 2004/09/12 00:15:47 niederberger Exp $
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -163,14 +164,30 @@ class HTMLAlbum:
 
     def showImgList(self,f,imagelist,pagepath):
         imglist = [] # is a list of lists like this: [href,imgsrc,thumbsrc,caption]
+
+        imagelist2 = []                 # this will be populated with (filename, id) tuples and then sorted and then iterated
+        # some images on imagelist are just ids: translate those to full paths, and reconstruct imagelist2
         for i in range(len(imagelist)):
-            #save thumbnail
-            imgid = -1
             if type(imagelist[i])==int:
                 imgid = imagelist[i]
-                imagelist[i] = self.curdb.img[imgid][0]
-            filen = os.path.split(imagelist[i])[-1] # filen = filename (NO path)
-            nfilen = imagelist[i]       # nfilen = full filename (WITH path) -- if on inplace mode, this will be replaced by a hashed filename, which will be a copy of the respective image.
+                imagelist2.append((self.curdb.img[imgid][0],imgid))
+            else:
+                imagelist2.append((imagelist[i], -1))
+                
+        # sort imagelist before displaying
+        def srt_fname(x,y):
+            if x[0]>y[0]:
+                return 1
+            else:
+                return -1
+        
+        imagelist2.sort(srt_fname)
+                
+        for i in range(len(imagelist2)):
+            #save thumbnail
+            imgid = imagelist2[i][1]
+            filen = os.path.split(imagelist2[i][0])[-1] # filen = filename (NO path)
+            nfilen = imagelist2[i][0]       # nfilen = full filename (WITH path) -- if on inplace mode, this will be replaced by a hashed filename, which will be a copy of the respective image.
             filenhs = self.curdb.uniquename(nfilen,".png")
             if not os.path.exists(pagepath+filenhs):
                 try:
@@ -206,7 +223,7 @@ class HTMLAlbum:
                         traceback.print_exc()
                         pass
             else:
-                captions = captions+os.path.split(imagelist[i])[-1]+"<br>"
+                captions = captions+os.path.split(imagelist2[i][0])[-1]+"<br>"
             captions = captions+"</font>"
             imglist.append([filen,filenhs,captions])
         self.showImgs(f,imglist)
@@ -337,7 +354,7 @@ class HTMLAlbum:
         subhtf.close()
         # copy style files to dir
         if not self.symmode: self.cpStyle(path)
-        print "PAGENAME" , pagename
+        #print "PAGENAME" , pagename
         return pagename
 
     def pagePath(self,path,header = ""):
@@ -383,9 +400,11 @@ class HTMLAlbum:
         # copy style files to dir
         if not self.symmode: self.cpStyle(path)
         return pagename
+    
     def textParentFolder(self,pagename):
         """returns the text to be included when you want a link to the parent folder which is pointed by pagename """
         return "<img border = 0 src=\"uparrow.png\"><a href=\""+pagename+"\">Parent folder</a>"
+    
     def showSubs(self,f,subs):
         """write subdirs inside this page """
         # [href,caption,info]
@@ -397,6 +416,7 @@ class HTMLAlbum:
             else:
                 txt = txt+"<img border=0 src=\"right.png\"><a href=\"" + i[0] + "\">"+i[1]+"</a><br>"
         self.frame(f,txt)
+        
     def showImgs(self,f,imglist):
         """ write to f all the images in imglist where imglist is:"""
         # [href,imgsrc,caption]
@@ -410,12 +430,20 @@ class HTMLAlbum:
             if not self.leafpage:
                 tntarget = imglist[i][0][:rfind(imglist[i][0],'.')]+".htm"
                 singleimagefile = open(self.destdir+tntarget,"w")
-                self.header(singleimagefile)
+                self.header(singleimagefile,imglist[i][0])
                 header = self.textParentFolder(self.serverroot+f.name[f.name.rfind("/")+1:])
                 #print "Header ist ",header
                 self.frame(singleimagefile,header)
                 self.frame(singleimagefile,"<center><a href=\""+imglist[i][0]+"\">"+"<img border = 0 width=800 src=\""+imglist[i][0]+"\"></a><br><font size=\"-1\">"+imglist[i][2]+"</font></center>")
-                self.footer(singleimagefile)
+                if (i-1) < 0:
+                    prevImgLink = ""
+                else:
+                    prevImgLink = "<a href=\"" + imglist[i-1][0][:rfind(imglist[i-1][0],'.')]+".htm\"><img border=0 src=\"left.png\" alt=\"Previous Image\"></a>"
+                if (i+1) >= len(imglist):
+                    nextImgLink = ""
+                else:
+                    nextImgLink = "<a href=\"" + imglist[i+1][0][:rfind(imglist[i+1][0],'.')]+".htm\"><img border=0 src=\"right.png\" alt=\"Next Image\"></a>"
+                self.footer(singleimagefile,prevImgLink,nextImgLink)
                 singleimagefile.close()
             else:
                 tntarget = imglist[i][0]
@@ -423,6 +451,7 @@ class HTMLAlbum:
                        imglist[i][2]+"</font></center>")
             f.write("</td>")
         f.write("""</table>""")
+        
     def header(self,f,title = "Photo Album"):
         f.write("""
 <!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">
@@ -436,18 +465,22 @@ class HTMLAlbum:
 </head>
 <body background=\"bg.png\" dir=\"ltr\">
 """)
-    def footer(self,f):
+
+    def footer(self,f,prevImgLink="",nextImgLink=""):
         f.write("""
+<hr>""" + prevImgLink + " " + nextImgLink + """
 <hr>
 Generated by <a href=\"http://imgseek.sourceforge.net\">imgSeek</a> - """ +time.asctime(time.localtime()) + """
 </body>
 </html>
 """)
+
     def section(self,f,title = ""):
         self.frame(f,"""<center><h2>"""+title+"""</h2></center>""")
 
     def frame(self,f,txt = ""):
         f.write(self.getframetext(txt))
+        
     def getframetext(self,txt = ""):
         return """
 <table border=\"0\" cellspacing=\"0\" cellpadding=\"0\">
