@@ -1,8 +1,9 @@
+# -*- coding: iso-8859-1 -*-
 ###############################################################################
 # begin                : Sat Dec 14 2002
 # copyright            : (C) 2003 by Ricardo Niederberger Cabral
 # email                : nieder at mail dot ru
-# $Id: ImgDB.py,v 1.257 2004/03/08 15:56:26 niederberger Exp $
+# $Id: ImgDB.py,v 1.263 2004/09/12 00:36:53 niederberger Exp $
 ###############################################################################
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,6 +18,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#
 ###############################################################################
 
 """Database module
@@ -75,6 +77,7 @@ class AddFilter:
         self.ignext = env.doc_ext
         self.exexif = 0
         self.exiptc = 0
+        self.followsym = 1
         self.mounted = 0
         self.probeext = 0
         self.addfname = ""
@@ -98,7 +101,16 @@ class ImgDB:
         self.env = env
         self.imgdb = imgdb
         #### image metadata:
-        self.imageParms = ["Description","Dimensions","Filesize","Filename","Format","Modify date","Database date","Modify_date_epoch"] # default meta keys all image should have
+        self.imageParms = ["Description",
+                           "Dimensions",
+                           "Filesize",
+                           "Filename",
+                           "Format",
+                           "Modify date",
+                           "Database date",
+                           "Modify_date_epoch",
+                           "Mounted"] # default meta keys all image should have
+
         self.blankMetaDict = {}           # blank dictionary with available keys. To be copied later to every new db file
         for par in self.imageParms:
             self.blankMetaDict[par] = None
@@ -173,7 +185,7 @@ class ImgDB:
     def reset(self):
         """ reset current db, should be called on File-> New """
         ## reseting all data structures
-        self.img = {}                   # key is id, value is [0-path,1-parent dir id, 2-[group ids]]
+        self.img = {}                   # key is id, value is [0-fullpath, 1-parent dir id, 2-[group ids]]
         self.meta = {}                  # key is id, value is dictionary of meta values
         self.dirs = {}                  # key id, value is [0-full path (/ at end),1-parent dir id,2-child dir ids,3-child files ids,4-child imgs filenames,5-description,6-volumeid]
         self.volumes = {}               # key id, value is [0-list of dir ids on this volume,1-base path,2-description,3-name]
@@ -907,6 +919,7 @@ class ImgDB:
                     break
             if os.path.isdir(path+file) and recursive:
                 if file[0]=='.': continue # do not add dirs starting with . (also excludes .thumbnail dirs)
+                if os.path.islink(path+file) and not restr.followsym: continue # don't follow symbolic links to directories                
                 # update paths tree
                 thasimg = self.addDir(volid,path+file,groupid,aborted,recursive,ndid,restr = restr)
                 if self.wnd:            # update progress on GUI
@@ -1400,10 +1413,11 @@ class ImgDB:
             if it[0]=="Group":
                 self.crawlGroupForImg(it[1],idlist)
             if it[0]=="Img":
-                if dumpids:
-                    idlist.append(it[1])
-                else:
-                    idlist.append(self.img[it[1]][0])
+                idlist.append(it[1])
+
+        if not dumpids:                 # caller wants fullpaths instead of ids
+            for i in range(len(idlist)):
+                idlist[i] = self.img[idlist[i]][0]
 
     def crawlBatchForFile(self,bid,idlist):
         """ here bid is the a batch id of a batch in db
@@ -1873,12 +1887,17 @@ class ImgDB:
         @type numres: int
         @return: list of pairs [img_id,0]. (0 is fixed and should be ignored.) What matters is the img_id integer, which means this image is a query result
         """
+        #TODO2: document the logic for this function. I can't even understand it now...
         res = []
         metaq = txt[0]
         logic = txt[1]
         pres = []
+
         for fi in range(len(metaq)):
             pres.append([])
+        if not pres:                    # there is no sense in a query with no keywords
+            return
+
         for fil in self.meta.keys():
             for fi in range(len(pres)):
                 try:
@@ -1892,7 +1911,8 @@ class ImgDB:
                 except:
                     traceback.print_exc()
                     pass
-        if logic=="AND":
+
+        if logic == "AND":
             min = 0
             for fi in range(len(pres)):
                 if len(pres[fi]) < len(pres[min]):
@@ -1904,10 +1924,11 @@ class ImgDB:
                         failed = 1
                         break
                 if not failed and id not in res: res.append(id)
-        elif logic=="OR":
+        elif logic == "OR":
             for fi in range(len(pres)):
                 for id in pres[fi]:
                     if id not in res: res.append(id)
+
         fres = []
         for id in res:
             fres.append([id,0])
@@ -2029,7 +2050,8 @@ class ImgDB:
         for nfid in ids:
             fname = self.img[nfid][0]
             try:
-                if not self.meta.has_key(nfid): self.meta[nfid] = self.blankMetaDict.copy()
+                if not self.meta.has_key(nfid):
+                    self.meta[nfid] = self.blankMetaDict.copy()
                 try:
                     self.initImgMetadata(fname,nfid)
                 except:
