@@ -3,7 +3,7 @@
     begin                : Sat Dec 14 2002
     author               : (C) 2002 by Ricardo Niederberger Cabral
     email                : nieder|at|mail.ru
-    $Id: customWidgets.py,v 1.106 2004/03/04 13:31:46 niederberger Exp $
+    $Id: customWidgets.py,v 1.109 2004/09/12 00:15:47 niederberger Exp $
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,12 +19,13 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 """
-__version__ = "$Revision: 1.106 $"
+__version__ = "$Revision: 1.109 $"
 
-from string import *
+from string import *                    #TODO2: ugly. Remove this import later
 import os
 import traceback
 import Error
+import sys
 
 try:
     from qt import *
@@ -171,6 +172,7 @@ class MouseMoveLabel(QLabel):
         self.mousePressed = 0
         self.mvCallback = None
         self.setScaledContents(0)
+        self.accrotate = 0              # amount of rotation accumulated so far. (used on doRotate)
         self.initPos = [0,0]
         self.setText("\n\n\timgSeek %s\n\thttp://imgseek.sf.net/\t\n\n"%__version__)
         self.origPixmap = None            # natural size pixmap
@@ -195,7 +197,6 @@ class MouseMoveLabel(QLabel):
         self.imgmenu.insertItem (self.env.wnd.globalslide.iconSet(), "F&ullscreen", self.onFullScreen)
         self.imgmenu.insertSeparator()
         self.imgmenu.insertItem ( "&External program ...", self.onExec)
-        import sys
         if sys.platform.find('win') == -1:  # *nix platform. This option is currently only available on *NIX
             self.imgmenu.insertItem ( "Set as desktop bac&kground", self.onSetBg)
         self.imgmenu.insertSeparator()
@@ -210,7 +211,7 @@ class MouseMoveLabel(QLabel):
 
     def onSetBg(self):
         if sys.platform.find('win') != -1:  # windows platform
-            pass #TODO: port to windows, and update the method above this one
+            pass #TODO: port to windows, and update the method above this one (createMenus)
         else:
             from Settings import binpathfinder
             prog = binpathfinder("bsetbg")
@@ -284,16 +285,19 @@ class MouseMoveLabel(QLabel):
         try:
             m = QWMatrix()
             m.rotate(fac)
-            aIm = self.pixmap().convertToImage().xForm(m)
+            aIm = self.pixmap().convertToImage().xForm(m) # temporary pixmap
             a = self.pixmap()
             del a
             aP = QPixmap()
             aP.convertFromImage(aIm)
             self.setPixmap(aP)
-            self.accrotate = self.accrotate+fac
+            self.accrotate = self.accrotate + fac
             # tell database we rotated this image
             if self.fid != -1:          # of course, only if this image is actually on db
-                self.env.curdb.changedDB({"scope":"Img","reason":"viewtransformed","transform":str(self.accrotate),"subject":self.fid})
+                self.env.curdb.changedDB({"scope":"Img",
+                                          "reason":"viewtransformed",
+                                          "transform":str(self.accrotate),
+                                          "subject":self.fid})
         except:
             traceback.print_exc()
             QMessageBox.information( self, "imgSeek","Error rotating image or invalid factor provided.")
@@ -309,7 +313,7 @@ class MouseMoveLabel(QLabel):
         self.accrotate = 0                # reset the "rotation-accumulator"
 
     def onFit(self):
-        if int(self.env.options["view.smoothscale"]):
+        if str(self.env.options["view.smoothscale"]) == '1' or str(self.env.options["view.smoothscale"]) == 'True':
             aIm = self.pixmap().convertToImage().smoothScale ( self.sview.visibleWidth(), self.sview.visibleHeight(), QImage.ScaleMin)
         else:
             aIm = self.pixmap().convertToImage().scale ( self.sview.visibleWidth(), self.sview.visibleHeight(), QImage.ScaleMin)
@@ -353,8 +357,11 @@ class MouseMoveLabel(QLabel):
     def mouseReleaseEvent(self,e):
         self.setCursor(QCursor(Qt.PointingHandCursor))
         self.mousePressed = 0
-        delta = [e.x()-self.initPos[0],e.y()-self.initPos[1]]
-        if self.mvCallback: self.mvCallback(delta)
+        delta = [e.x()-self.initPos[0], e.y()-self.initPos[1]]
+        if self.mvCallback:
+            self.mvCallback(delta)
+        else:
+            print 'no mv callback set on mouse release event'
 
 class ImgViewScroll(QScrollView):
     def __init__(self, *args):
@@ -381,6 +388,7 @@ class ImgViewScroll(QScrollView):
         if self.pixlabel.fname==fname:return # dont display image if it's already displayed
         imgDim=""                       # resolve later to image dimensions
         self.pixlabel.infolabel = self.infolabel
+
         if int(self.env.options["view.autofit"]):
             fit = 1
         if fit:
@@ -406,6 +414,8 @@ class ImgViewScroll(QScrollView):
         self.pixlabel.fname = fname
         self.pixlabel.fid = fid
         self.pixlabel.accrotate = 0
+
+        #TODO2: these view transforms (aka rotations) should happen before fitting image to window. That would fix bug #959344
         if fid != -1:                   # check for view transforms
             if self.env.curdb.meta.has_key(fid):
                 if self.env.curdb.meta[fid].has_key("ViewRotate"):
